package com.mints.goodmoney.ad.video

import android.app.Activity
import com.mints.goodmoney.ad.video.base.BaseVideoAd
import com.mints.goodmoney.ad.video.base.VideoAdStatusListener
import com.mints.goodmoney.common.AppConfig
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.manager.OwManager
import com.mints.goodmoney.manager.TrackManager
import mobi.oneway.export.Ad.OWRewardedAd
import mobi.oneway.export.AdListener.OWRewardedAdListener
import mobi.oneway.export.enums.OnewayAdCloseType
import mobi.oneway.export.enums.OnewaySdkError

private val TAG = OwVideoAdManager::class.java.simpleName

/**
 * OneWay广告视频
 */
class OwVideoAdManager private constructor() :
        BaseVideoAd() {

    private var videoAdStatusListener: VideoAdStatusListener? = null
    private var owRewardedAd: OWRewardedAd? = null

    private var isClickScreen: Boolean = true

    companion object {
        private var _inst: OwVideoAdManager? = null
        fun getInstance(): OwVideoAdManager? {
            return if (_inst != null) {
                _inst
            } else {
                _inst = OwVideoAdManager()
                _inst
            }
        }
    }

    override fun loadAd(activity: Activity, curCoin: Int, carrierType: String, extraId: String?) {
        isClickScreen = true

        //创建激励视频事件监听器
        val owRewardedAdListener: OWRewardedAdListener = object : OWRewardedAdListener {
            override fun onAdReady() {
                owRewardedAd?.show(activity)
            }

            override fun onAdShow(tag: String) {
                TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_OW, Constant.EVENT_TYPE_ZERO, "", "")
            }

            override fun onAdClick(tag: String) {
                if (AppConfig.needReportClickAdEvent) {
                    TrackManager.getInstance().reportClickAdEvent()
                }

                TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_OW, Constant.EVENT_TYPE_TWO, "", "")
                if (isClickScreen) {
                    // 防止重复
                    TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_OW, Constant.EVENT_TYPE_FOUR, "", "")
                    isClickScreen = false
                }

                videoAdStatusListener?.adDownload()
            }

            override fun onAdClose(tag: String, onewayVideoCloseType: OnewayAdCloseType) {
                TrackManager.getInstance().reportAddCoinMsg(activity, getAdMapVO(carrierType, Constant.AD_SOURCE_OW, extraId, curCoin))

                TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_OW, Constant.EVENT_TYPE_THREE, "", "")

                videoAdStatusListener?.adSuccess()
            }

            override fun onAdFinish(s: String, onewayAdCloseType: OnewayAdCloseType, s1: String) {
            }

            override fun onSdkError(onewaySdkError: OnewaySdkError, msg: String) {
                TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_OW, Constant.EVENT_TYPE_ONE, "999999", "emun:" + onewaySdkError.name + "msg:" + msg)

                videoAdStatusListener?.adFail()
            }
        }

        //创建激励视频对象
        owRewardedAd = OWRewardedAd(activity, OwManager.REWARD_PID, owRewardedAdListener)

        owRewardedAd?.loadAd()
    }

    fun setVideoAdStatusListener(videoAdStatusListener: VideoAdStatusListener?) {
        this.videoAdStatusListener = videoAdStatusListener
    }

    override fun onDestroy() {
        owRewardedAd?.destory()
        owRewardedAd = null
    }
}